@@ -76,6 +76,8 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 		workflow.go()
 	"""
 
+	config.logger.info("###### Start assembly module ######")
+
 	time_equation = config.time  # xxx hours defined in global config
 	mem_equation = config.memory  # xxx GB defined in global config
 
@@ -164,7 +166,6 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 				f_seq = tmp[0]
 				r_seq = tmp[1]
 				if myorphan != "none":
-					#print(sample + " megahit: " + mypair + "\t" + myorphan)
 					workflow.add_task_gridable("rm -rf " + megahit_contig_dir + " && " + "megahit -1 [depends[0]] -2 [depends[1]] -r [args[2]] -t [args[0]] -o [args[3]] --out-prefix [args[1]] >[args[4]] 2>&1",
 									depends = [f_seq, r_seq, TrackedExecutable("megahit")],
 									targets = [megahit_contig],
@@ -174,7 +175,6 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 									time = time_equation,
 									name = sample + "__megahit")
 				else:
-					#print(sample + " megahit: " + "\t" + mypair)
 					workflow.add_task_gridable("rm -rf " + megahit_contig_dir + " && " + "megahit -1 [depends[0]] -2 [depends[1]] -t [args[0]] -o [args[2]] --out-prefix [args[1]] >[args[3]] 2>&1",
 									depends = [f_seq, r_seq, TrackedExecutable("megahit")],
 									targets = [megahit_contig],
@@ -184,7 +184,6 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 									time = time_equation,
 									name = sample + "__megahit")
 			else:
-				#print(sample + " megahit: " + "\t" + mypair)
 				workflow.add_task_gridable("rm -rf " + megahit_contig_dir + " && " + "megahit -r [depends[0]] -t [args[0]] -o [args[2]] --out-prefix [args[1]] >[args[3]] 2>&1",
 									depends = [mypair, TrackedExecutable("megahit")],
 									targets = [megahit_contig],
@@ -194,8 +193,7 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 									time = time_equation,
 									name = sample + "__megahit")
 		else:
-			if myorphan != "none":	
-				#print(sample + " megahit: " + "\t" + myorphan)
+			if myorphan != "none":
 				workflow.add_task_gridable("rm -rf " + megahit_contig_dir + " && " + "megahit -r [depends[0]] -t [args[0]] -o [args[2]] --out-prefix [args[1]] >[args[3]] 2>&1",
 								depends = [myorphan, TrackedExecutable("megahit")],
 								targets = [megahit_contig],
@@ -217,7 +215,7 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 
 
 	## combine contigs sequences
-	mylog = contig + ".log" 
+	mylog = contigs + ".log" 
 	workflow.add_task(
 		"metawibele_format_contig_sequences -p [args[0]] -e contigs.fa -o [targets[0]] > [args[1]] 2>&1",
 		depends=utilities.add_to_list(contigs_list, TrackedExecutable("metawibele_format_contig_sequences")),
@@ -226,6 +224,7 @@ def assembly (workflow, input_dir, extension, extension_paired, threads, output_
 		cores = 1,
 		name="format_contig_table")
 
+
 	return contigs_list
 
 
@@ -276,6 +275,8 @@ def gene_calling (workflow, assembly_dir, assembly_extentsion, input_dir, extens
 		workflow.go()
 	"""
 
+	config.logger.info("###### Start gene_calling module ######")
+
 	time_equation = config.time  # xxx hours defined in global config
 	mem_equation = config.memory  # xxx GB defined in global config
 
@@ -493,6 +494,7 @@ def gene_calling (workflow, assembly_dir, assembly_extentsion, input_dir, extens
 				cores = 1,
 				name = 'extract_complete_ORF_seq')
 
+
 	return complete_gene, complete_protein
 
 
@@ -543,6 +545,8 @@ def gene_catalog (workflow, complete_gene, complete_protein,
         workflow.go()
     """
 
+	config.logger.info("###### Start gene_catalog module ######")
+
 	time_equation = config.time # xxx hours defined in global config
 	mem_equation = config.memory  # xxx GB defined in global config
 
@@ -655,5 +659,6 @@ def gene_catalog (workflow, complete_gene, complete_protein,
 				cores = 1,
 				name = "gene_catalog_abundance")
 
+
 	return gene_catalog, gene_catalog_count
 
